@@ -77,7 +77,7 @@ guint            y_expanded_offset = 20;
 
 gchar* game_file_to_name (const gchar* file)
 {
-  char* p, *buf = g_strdup (g_path_get_basename(file));
+  char* p, *buf = g_path_get_basename(file);
 
   if ((p = strrchr (buf, '.'))) *p = '\0';
   for(p = buf; p = strchr(p, '_'), p && *p;) *p = ' ';
@@ -137,7 +137,7 @@ void eval_installed_file (char *file)
   
   relative = g_strconcat (GAMESDIR, file, NULL);
   installed_filename = gnome_program_locate_file (NULL, 
-                                                  GNOME_FILE_DOMAIN_DATADIR,
+                                                  GNOME_FILE_DOMAIN_APP_DATADIR,
                                                   relative,
                                                   FALSE, NULL);
 
@@ -355,8 +355,32 @@ void create_sol_board ()
 		      GTK_SIGNAL_FUNC (button_press_event), NULL);
 }
 
-void quit_app (GtkWidget *app)
+gboolean quit_app (GtkMenuItem *menuitem)
 {
+  GtkWidget *box;
+  gint response;
+
+  if (!game_over) {
+    box = gtk_message_dialog_new (GTK_WINDOW (app),
+            GTK_DIALOG_MODAL,
+            GTK_MESSAGE_QUESTION,
+            GTK_BUTTONS_NONE,
+            _("Really exit Aisleriot?"));
+    gtk_dialog_add_buttons (GTK_DIALOG (box),
+            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+            GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+            NULL);
+
+    
+    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_REJECT);
+
+    response = gtk_dialog_run (GTK_DIALOG (box));
+    gtk_widget_destroy (box);
+
+    if (response == GTK_RESPONSE_REJECT)
+        return TRUE;
+  }
+  
   gtk_widget_destroy (app);
   gtk_main_quit ();
 }
@@ -527,7 +551,7 @@ int main (int argc, char *argv [])
 
   retrieve_state (gnome_master_client ());
 
-  dir = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_DATADIR,
+  dir = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
 	                                        GAMESDIR, FALSE, NULL);
 
   records = scandir (dir, &game_dents, is_game, alphasort);
@@ -538,12 +562,16 @@ int main (int argc, char *argv [])
   else
 	  n_games = 0;
 
-  for (i = 0; i < n_games; i++)
-    if (!strcasecmp (variation, game_file_to_name (game_dents[i]->d_name))) {
+  for (i = 0; i < n_games; i++) {
+    gchar *game_name = game_file_to_name (game_dents[i]->d_name);
+    if (!strcasecmp (variation, game_name)) {
       start_game = g_strdup ((gchar*) game_dents[i]->d_name);
+      g_free (game_name);
       break;
     }
-
+    g_free (game_name);
+  }
+  
   gh_enter(argc, argv, main_prog);
   return 0;
 }
