@@ -549,7 +549,7 @@ callback_score (GtkWidget *widget, GdkEvent *event)
 {
   GtkWidget *dialog;
 
-  dialog = score_dialog(GTK_WINDOW (main_window)); 
+  dialog = score_dialog(); 
 }
 
 void
@@ -622,7 +622,7 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
 		      GTK_BUTTONS_NONE,
-		      _("Exit this game?"),
+		      _("Really exit GNOME Freecell?"),
 		      NULL);
       gtk_dialog_add_buttons (GTK_DIALOG (mb),
 			      GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
